// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package admin aliases all exported identifiers in package
// "cloud.google.com/go/analytics/admin/apiv1alpha/adminpb".
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package admin

import (
	src "cloud.google.com/go/analytics/admin/apiv1alpha/adminpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
const (
	AccessNumericFilter_EQUAL                                                    = src.AccessNumericFilter_EQUAL
	AccessNumericFilter_GREATER_THAN                                             = src.AccessNumericFilter_GREATER_THAN
	AccessNumericFilter_GREATER_THAN_OR_EQUAL                                    = src.AccessNumericFilter_GREATER_THAN_OR_EQUAL
	AccessNumericFilter_LESS_THAN                                                = src.AccessNumericFilter_LESS_THAN
	AccessNumericFilter_LESS_THAN_OR_EQUAL                                       = src.AccessNumericFilter_LESS_THAN_OR_EQUAL
	AccessNumericFilter_OPERATION_UNSPECIFIED                                    = src.AccessNumericFilter_OPERATION_UNSPECIFIED
	AccessOrderBy_DimensionOrderBy_ALPHANUMERIC                                  = src.AccessOrderBy_DimensionOrderBy_ALPHANUMERIC
	AccessOrderBy_DimensionOrderBy_CASE_INSENSITIVE_ALPHANUMERIC                 = src.AccessOrderBy_DimensionOrderBy_CASE_INSENSITIVE_ALPHANUMERIC
	AccessOrderBy_DimensionOrderBy_NUMERIC                                       = src.AccessOrderBy_DimensionOrderBy_NUMERIC
	AccessOrderBy_DimensionOrderBy_ORDER_TYPE_UNSPECIFIED                        = src.AccessOrderBy_DimensionOrderBy_ORDER_TYPE_UNSPECIFIED
	AccessStringFilter_BEGINS_WITH                                               = src.AccessStringFilter_BEGINS_WITH
	AccessStringFilter_CONTAINS                                                  = src.AccessStringFilter_CONTAINS
	AccessStringFilter_ENDS_WITH                                                 = src.AccessStringFilter_ENDS_WITH
	AccessStringFilter_EXACT                                                     = src.AccessStringFilter_EXACT
	AccessStringFilter_FULL_REGEXP                                               = src.AccessStringFilter_FULL_REGEXP
	AccessStringFilter_MATCH_TYPE_UNSPECIFIED                                    = src.AccessStringFilter_MATCH_TYPE_UNSPECIFIED
	AccessStringFilter_PARTIAL_REGEXP                                            = src.AccessStringFilter_PARTIAL_REGEXP
	ActionType_ACTION_TYPE_UNSPECIFIED                                           = src.ActionType_ACTION_TYPE_UNSPECIFIED
	ActionType_CREATED                                                           = src.ActionType_CREATED
	ActionType_DELETED                                                           = src.ActionType_DELETED
	ActionType_UPDATED                                                           = src.ActionType_UPDATED
	ActorType_ACTOR_TYPE_UNSPECIFIED                                             = src.ActorType_ACTOR_TYPE_UNSPECIFIED
	ActorType_SUPPORT                                                            = src.ActorType_SUPPORT
	ActorType_SYSTEM                                                             = src.ActorType_SYSTEM
	ActorType_USER                                                               = src.ActorType_USER
	AttributionSettings_ACQUISITION_CONVERSION_EVENT_LOOKBACK_WINDOW_30_DAYS     = src.AttributionSettings_ACQUISITION_CONVERSION_EVENT_LOOKBACK_WINDOW_30_DAYS
	AttributionSettings_ACQUISITION_CONVERSION_EVENT_LOOKBACK_WINDOW_7_DAYS      = src.AttributionSettings_ACQUISITION_CONVERSION_EVENT_LOOKBACK_WINDOW_7_DAYS
	AttributionSettings_ACQUISITION_CONVERSION_EVENT_LOOKBACK_WINDOW_UNSPECIFIED = src.AttributionSettings_ACQUISITION_CONVERSION_EVENT_LOOKBACK_WINDOW_UNSPECIFIED
	AttributionSettings_OTHER_CONVERSION_EVENT_LOOKBACK_WINDOW_30_DAYS           = src.AttributionSettings_OTHER_CONVERSION_EVENT_LOOKBACK_WINDOW_30_DAYS
	AttributionSettings_OTHER_CONVERSION_EVENT_LOOKBACK_WINDOW_60_DAYS           = src.AttributionSettings_OTHER_CONVERSION_EVENT_LOOKBACK_WINDOW_60_DAYS
	AttributionSettings_OTHER_CONVERSION_EVENT_LOOKBACK_WINDOW_90_DAYS           = src.AttributionSettings_OTHER_CONVERSION_EVENT_LOOKBACK_WINDOW_90_DAYS
	AttributionSettings_OTHER_CONVERSION_EVENT_LOOKBACK_WINDOW_UNSPECIFIED       = src.AttributionSettings_OTHER_CONVERSION_EVENT_LOOKBACK_WINDOW_UNSPECIFIED
	AttributionSettings_REPORTING_ATTRIBUTION_MODEL_UNSPECIFIED                  = src.AttributionSettings_REPORTING_ATTRIBUTION_MODEL_UNSPECIFIED
	AudienceDimensionOrMetricFilter_NumericFilter_EQUAL                          = src.AudienceDimensionOrMetricFilter_NumericFilter_EQUAL
	AudienceDimensionOrMetricFilter_NumericFilter_GREATER_THAN                   = src.AudienceDimensionOrMetricFilter_NumericFilter_GREATER_THAN
	AudienceDimensionOrMetricFilter_NumericFilter_LESS_THAN                      = src.AudienceDimensionOrMetricFilter_NumericFilter_LESS_THAN
	AudienceDimensionOrMetricFilter_NumericFilter_OPERATION_UNSPECIFIED          = src.AudienceDimensionOrMetricFilter_NumericFilter_OPERATION_UNSPECIFIED
	AudienceDimensionOrMetricFilter_StringFilter_BEGINS_WITH                     = src.AudienceDimensionOrMetricFilter_StringFilter_BEGINS_WITH
	AudienceDimensionOrMetricFilter_StringFilter_CONTAINS                        = src.AudienceDimensionOrMetricFilter_StringFilter_CONTAINS
	AudienceDimensionOrMetricFilter_StringFilter_ENDS_WITH                       = src.AudienceDimensionOrMetricFilter_StringFilter_ENDS_WITH
	AudienceDimensionOrMetricFilter_StringFilter_EXACT                           = src.AudienceDimensionOrMetricFilter_StringFilter_EXACT
	AudienceDimensionOrMetricFilter_StringFilter_FULL_REGEXP                     = src.AudienceDimensionOrMetricFilter_StringFilter_FULL_REGEXP
	AudienceDimensionOrMetricFilter_StringFilter_MATCH_TYPE_UNSPECIFIED          = src.AudienceDimensionOrMetricFilter_StringFilter_MATCH_TYPE_UNSPECIFIED
	AudienceEventTrigger_AUDIENCE_JOINED                                         = src.AudienceEventTrigger_AUDIENCE_JOINED
	AudienceEventTrigger_AUDIENCE_MEMBERSHIP_RENEWED                             = src.AudienceEventTrigger_AUDIENCE_MEMBERSHIP_RENEWED
	AudienceEventTrigger_LOG_CONDITION_UNSPECIFIED                               = src.AudienceEventTrigger_LOG_CONDITION_UNSPECIFIED
	AudienceFilterClause_AUDIENCE_CLAUSE_TYPE_UNSPECIFIED                        = src.AudienceFilterClause_AUDIENCE_CLAUSE_TYPE_UNSPECIFIED
	AudienceFilterClause_EXCLUDE                                                 = src.AudienceFilterClause_EXCLUDE
	AudienceFilterClause_INCLUDE                                                 = src.AudienceFilterClause_INCLUDE
	AudienceFilterScope_AUDIENCE_FILTER_SCOPE_ACROSS_ALL_SESSIONS                = src.AudienceFilterScope_AUDIENCE_FILTER_SCOPE_ACROSS_ALL_SESSIONS
	AudienceFilterScope_AUDIENCE_FILTER_SCOPE_UNSPECIFIED                        = src.AudienceFilterScope_AUDIENCE_FILTER_SCOPE_UNSPECIFIED
	AudienceFilterScope_AUDIENCE_FILTER_SCOPE_WITHIN_SAME_EVENT                  = src.AudienceFilterScope_AUDIENCE_FILTER_SCOPE_WITHIN_SAME_EVENT
	AudienceFilterScope_AUDIENCE_FILTER_SCOPE_WITHIN_SAME_SESSION                = src.AudienceFilterScope_AUDIENCE_FILTER_SCOPE_WITHIN_SAME_SESSION
	Audience_AUDIENCE_EXCLUSION_DURATION_MODE_UNSPECIFIED                        = src.Audience_AUDIENCE_EXCLUSION_DURATION_MODE_UNSPECIFIED
	Audience_EXCLUDE_PERMANENTLY                                                 = src.Audience_EXCLUDE_PERMANENTLY
	Audience_EXCLUDE_TEMPORARILY                                                 = src.Audience_EXCLUDE_TEMPORARILY
	ChangeHistoryResourceType_ACCOUNT                                            = src.ChangeHistoryResourceType_ACCOUNT
	ChangeHistoryResourceType_ATTRIBUTION_SETTINGS                               = src.ChangeHistoryResourceType_ATTRIBUTION_SETTINGS
	ChangeHistoryResourceType_CHANGE_HISTORY_RESOURCE_TYPE_UNSPECIFIED           = src.ChangeHistoryResourceType_CHANGE_HISTORY_RESOURCE_TYPE_UNSPECIFIED
	ChangeHistoryResourceType_CONVERSION_EVENT                                   = src.ChangeHistoryResourceType_CONVERSION_EVENT
	ChangeHistoryResourceType_CUSTOM_DIMENSION                                   = src.ChangeHistoryResourceType_CUSTOM_DIMENSION
	ChangeHistoryResourceType_CUSTOM_METRIC                                      = src.ChangeHistoryResourceType_CUSTOM_METRIC
	ChangeHistoryResourceType_DATA_RETENTION_SETTINGS                            = src.ChangeHistoryResourceType_DATA_RETENTION_SETTINGS
	ChangeHistoryResourceType_DATA_STREAM                                        = src.ChangeHistoryResourceType_DATA_STREAM
	ChangeHistoryResourceType_DISPLAY_VIDEO_360_ADVERTISER_LINK                  = src.ChangeHistoryResourceType_DISPLAY_VIDEO_360_ADVERTISER_LINK
	ChangeHistoryResourceType_DISPLAY_VIDEO_360_ADVERTISER_LINK_PROPOSAL         = src.ChangeHistoryResourceType_DISPLAY_VIDEO_360_ADVERTISER_LINK_PROPOSAL
	ChangeHistoryResourceType_FIREBASE_LINK                                      = src.ChangeHistoryResourceType_FIREBASE_LINK
	ChangeHistoryResourceType_GOOGLE_ADS_LINK                                    = src.ChangeHistoryResourceType_GOOGLE_ADS_LINK
	ChangeHistoryResourceType_GOOGLE_SIGNALS_SETTINGS                            = src.ChangeHistoryResourceType_GOOGLE_SIGNALS_SETTINGS
	ChangeHistoryResourceType_MEASUREMENT_PROTOCOL_SECRET                        = src.ChangeHistoryResourceType_MEASUREMENT_PROTOCOL_SECRET
	ChangeHistoryResourceType_PROPERTY                                           = src.ChangeHistoryResourceType_PROPERTY
	ChangeHistoryResourceType_SEARCH_ADS_360_LINK                                = src.ChangeHistoryResourceType_SEARCH_ADS_360_LINK
	CustomDimension_DIMENSION_SCOPE_UNSPECIFIED                                  = src.CustomDimension_DIMENSION_SCOPE_UNSPECIFIED
	CustomDimension_EVENT                                                        = src.CustomDimension_EVENT
	CustomDimension_USER                                                         = src.CustomDimension_USER
	CustomMetric_COST_DATA                                                       = src.CustomMetric_COST_DATA
	CustomMetric_CURRENCY                                                        = src.CustomMetric_CURRENCY
	CustomMetric_EVENT                                                           = src.CustomMetric_EVENT
	CustomMetric_FEET                                                            = src.CustomMetric_FEET
	CustomMetric_HOURS                                                           = src.CustomMetric_HOURS
	CustomMetric_KILOMETERS                                                      = src.CustomMetric_KILOMETERS
	CustomMetric_MEASUREMENT_UNIT_UNSPECIFIED                                    = src.CustomMetric_MEASUREMENT_UNIT_UNSPECIFIED
	CustomMetric_METERS                                                          = src.CustomMetric_METERS
	CustomMetric_METRIC_SCOPE_UNSPECIFIED                                        = src.CustomMetric_METRIC_SCOPE_UNSPECIFIED
	CustomMetric_MILES                                                           = src.CustomMetric_MILES
	CustomMetric_MILLISECONDS                                                    = src.CustomMetric_MILLISECONDS
	CustomMetric_MINUTES                                                         = src.CustomMetric_MINUTES
	CustomMetric_RESTRICTED_METRIC_TYPE_UNSPECIFIED                              = src.CustomMetric_RESTRICTED_METRIC_TYPE_UNSPECIFIED
	CustomMetric_REVENUE_DATA                                                    = src.CustomMetric_REVENUE_DATA
	CustomMetric_SECONDS                                                         = src.CustomMetric_SECONDS
	CustomMetric_STANDARD                                                        = src.CustomMetric_STANDARD
	DataRetentionSettings_FIFTY_MONTHS                                           = src.DataRetentionSettings_FIFTY_MONTHS
	DataRetentionSettings_FOURTEEN_MONTHS                                        = src.DataRetentionSettings_FOURTEEN_MONTHS
	DataRetentionSettings_RETENTION_DURATION_UNSPECIFIED                         = src.DataRetentionSettings_RETENTION_DURATION_UNSPECIFIED
	DataRetentionSettings_THIRTY_EIGHT_MONTHS                                    = src.DataRetentionSettings_THIRTY_EIGHT_MONTHS
	DataRetentionSettings_TWENTY_SIX_MONTHS                                      = src.DataRetentionSettings_TWENTY_SIX_MONTHS
	DataRetentionSettings_TWO_MONTHS                                             = src.DataRetentionSettings_TWO_MONTHS
	DataStream_ANDROID_APP_DATA_STREAM                                           = src.DataStream_ANDROID_APP_DATA_STREAM
	DataStream_DATA_STREAM_TYPE_UNSPECIFIED                                      = src.DataStream_DATA_STREAM_TYPE_UNSPECIFIED
	DataStream_IOS_APP_DATA_STREAM                                               = src.DataStream_IOS_APP_DATA_STREAM
	DataStream_WEB_DATA_STREAM                                                   = src.DataStream_WEB_DATA_STREAM
	GoogleSignalsConsent_GOOGLE_SIGNALS_CONSENT_CONSENTED                        = src.GoogleSignalsConsent_GOOGLE_SIGNALS_CONSENT_CONSENTED
	GoogleSignalsConsent_GOOGLE_SIGNALS_CONSENT_NOT_CONSENTED                    = src.GoogleSignalsConsent_GOOGLE_SIGNALS_CONSENT_NOT_CONSENTED
	GoogleSignalsConsent_GOOGLE_SIGNALS_CONSENT_UNSPECIFIED                      = src.GoogleSignalsConsent_GOOGLE_SIGNALS_CONSENT_UNSPECIFIED
	GoogleSignalsState_GOOGLE_SIGNALS_DISABLED                                   = src.GoogleSignalsState_GOOGLE_SIGNALS_DISABLED
	GoogleSignalsState_GOOGLE_SIGNALS_ENABLED                                    = src.GoogleSignalsState_GOOGLE_SIGNALS_ENABLED
	GoogleSignalsState_GOOGLE_SIGNALS_STATE_UNSPECIFIED                          = src.GoogleSignalsState_GOOGLE_SIGNALS_STATE_UNSPECIFIED
	IndustryCategory_ARTS_AND_ENTERTAINMENT                                      = src.IndustryCategory_ARTS_AND_ENTERTAINMENT
	IndustryCategory_AUTOMOTIVE                                                  = src.IndustryCategory_AUTOMOTIVE
	IndustryCategory_BEAUTY_AND_FITNESS                                          = src.IndustryCategory_BEAUTY_AND_FITNESS
	IndustryCategory_BOOKS_AND_LITERATURE                                        = src.IndustryCategory_BOOKS_AND_LITERATURE
	IndustryCategory_BUSINESS_AND_INDUSTRIAL_MARKETS                             = src.IndustryCategory_BUSINESS_AND_INDUSTRIAL_MARKETS
	IndustryCategory_FINANCE                                                     = src.IndustryCategory_FINANCE
	IndustryCategory_FOOD_AND_DRINK                                              = src.IndustryCategory_FOOD_AND_DRINK
	IndustryCategory_GAMES                                                       = src.IndustryCategory_GAMES
	IndustryCategory_HEALTHCARE                                                  = src.IndustryCategory_HEALTHCARE
	IndustryCategory_HOBBIES_AND_LEISURE                                         = src.IndustryCategory_HOBBIES_AND_LEISURE
	IndustryCategory_HOME_AND_GARDEN                                             = src.IndustryCategory_HOME_AND_GARDEN
	IndustryCategory_INDUSTRY_CATEGORY_UNSPECIFIED                               = src.IndustryCategory_INDUSTRY_CATEGORY_UNSPECIFIED
	IndustryCategory_INTERNET_AND_TELECOM                                        = src.IndustryCategory_INTERNET_AND_TELECOM
	IndustryCategory_JOBS_AND_EDUCATION                                          = src.IndustryCategory_JOBS_AND_EDUCATION
	IndustryCategory_LAW_AND_GOVERNMENT                                          = src.IndustryCategory_LAW_AND_GOVERNMENT
	IndustryCategory_NEWS                                                        = src.IndustryCategory_NEWS
	IndustryCategory_ONLINE_COMMUNITIES                                          = src.IndustryCategory_ONLINE_COMMUNITIES
	IndustryCategory_OTHER                                                       = src.IndustryCategory_OTHER
	IndustryCategory_PEOPLE_AND_SOCIETY                                          = src.IndustryCategory_PEOPLE_AND_SOCIETY
	IndustryCategory_PETS_AND_ANIMALS                                            = src.IndustryCategory_PETS_AND_ANIMALS
	IndustryCategory_REAL_ESTATE                                                 = src.IndustryCategory_REAL_ESTATE
	IndustryCategory_REFERENCE                                                   = src.IndustryCategory_REFERENCE
	IndustryCategory_SCIENCE                                                     = src.IndustryCategory_SCIENCE
	IndustryCategory_SHOPPING                                                    = src.IndustryCategory_SHOPPING
	IndustryCategory_SPORTS                                                      = src.IndustryCategory_SPORTS
	IndustryCategory_TECHNOLOGY                                                  = src.IndustryCategory_TECHNOLOGY
	IndustryCategory_TRAVEL                                                      = src.IndustryCategory_TRAVEL
	LinkProposalInitiatingProduct_GOOGLE_ANALYTICS                               = src.LinkProposalInitiatingProduct_GOOGLE_ANALYTICS
	LinkProposalInitiatingProduct_LINKED_PRODUCT                                 = src.LinkProposalInitiatingProduct_LINKED_PRODUCT
	LinkProposalInitiatingProduct_LINK_PROPOSAL_INITIATING_PRODUCT_UNSPECIFIED   = src.LinkProposalInitiatingProduct_LINK_PROPOSAL_INITIATING_PRODUCT_UNSPECIFIED
	LinkProposalState_AWAITING_REVIEW_FROM_GOOGLE_ANALYTICS                      = src.LinkProposalState_AWAITING_REVIEW_FROM_GOOGLE_ANALYTICS
	LinkProposalState_AWAITING_REVIEW_FROM_LINKED_PRODUCT                        = src.LinkProposalState_AWAITING_REVIEW_FROM_LINKED_PRODUCT
	LinkProposalState_DECLINED                                                   = src.LinkProposalState_DECLINED
	LinkProposalState_EXPIRED                                                    = src.LinkProposalState_EXPIRED
	LinkProposalState_LINK_PROPOSAL_STATE_UNSPECIFIED                            = src.LinkProposalState_LINK_PROPOSAL_STATE_UNSPECIFIED
	LinkProposalState_OBSOLETE                                                   = src.LinkProposalState_OBSOLETE
	LinkProposalState_WITHDRAWN                                                  = src.LinkProposalState_WITHDRAWN
	PropertyType_PROPERTY_TYPE_ORDINARY                                          = src.PropertyType_PROPERTY_TYPE_ORDINARY
	PropertyType_PROPERTY_TYPE_ROLLUP                                            = src.PropertyType_PROPERTY_TYPE_ROLLUP
	PropertyType_PROPERTY_TYPE_SUBPROPERTY                                       = src.PropertyType_PROPERTY_TYPE_SUBPROPERTY
	PropertyType_PROPERTY_TYPE_UNSPECIFIED                                       = src.PropertyType_PROPERTY_TYPE_UNSPECIFIED
	ServiceLevel_GOOGLE_ANALYTICS_360                                            = src.ServiceLevel_GOOGLE_ANALYTICS_360
	ServiceLevel_GOOGLE_ANALYTICS_STANDARD                                       = src.ServiceLevel_GOOGLE_ANALYTICS_STANDARD
	ServiceLevel_SERVICE_LEVEL_UNSPECIFIED                                       = src.ServiceLevel_SERVICE_LEVEL_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
var (
	AccessNumericFilter_Operation_name                                 = src.AccessNumericFilter_Operation_name
	AccessNumericFilter_Operation_value                                = src.AccessNumericFilter_Operation_value
	AccessOrderBy_DimensionOrderBy_OrderType_name                      = src.AccessOrderBy_DimensionOrderBy_OrderType_name
	AccessOrderBy_DimensionOrderBy_OrderType_value                     = src.AccessOrderBy_DimensionOrderBy_OrderType_value
	AccessStringFilter_MatchType_name                                  = src.AccessStringFilter_MatchType_name
	AccessStringFilter_MatchType_value                                 = src.AccessStringFilter_MatchType_value
	ActionType_name                                                    = src.ActionType_name
	ActionType_value                                                   = src.ActionType_value
	ActorType_name                                                     = src.ActorType_name
	ActorType_value                                                    = src.ActorType_value
	AttributionSettings_AcquisitionConversionEventLookbackWindow_name  = src.AttributionSettings_AcquisitionConversionEventLookbackWindow_name
	AttributionSettings_AcquisitionConversionEventLookbackWindow_value = src.AttributionSettings_AcquisitionConversionEventLookbackWindow_value
	AttributionSettings_OtherConversionEventLookbackWindow_name        = src.AttributionSettings_OtherConversionEventLookbackWindow_name
	AttributionSettings_OtherConversionEventLookbackWindow_value       = src.AttributionSettings_OtherConversionEventLookbackWindow_value
	AttributionSettings_ReportingAttributionModel_name                 = src.AttributionSettings_ReportingAttributionModel_name
	AttributionSettings_ReportingAttributionModel_value                = src.AttributionSettings_ReportingAttributionModel_value
	AudienceDimensionOrMetricFilter_NumericFilter_Operation_name       = src.AudienceDimensionOrMetricFilter_NumericFilter_Operation_name
	AudienceDimensionOrMetricFilter_NumericFilter_Operation_value      = src.AudienceDimensionOrMetricFilter_NumericFilter_Operation_value
	AudienceDimensionOrMetricFilter_StringFilter_MatchType_name        = src.AudienceDimensionOrMetricFilter_StringFilter_MatchType_name
	AudienceDimensionOrMetricFilter_StringFilter_MatchType_value       = src.AudienceDimensionOrMetricFilter_StringFilter_MatchType_value
	AudienceEventTrigger_LogCondition_name                             = src.AudienceEventTrigger_LogCondition_name
	AudienceEventTrigger_LogCondition_value                            = src.AudienceEventTrigger_LogCondition_value
	AudienceFilterClause_AudienceClauseType_name                       = src.AudienceFilterClause_AudienceClauseType_name
	AudienceFilterClause_AudienceClauseType_value                      = src.AudienceFilterClause_AudienceClauseType_value
	AudienceFilterScope_name                                           = src.AudienceFilterScope_name
	AudienceFilterScope_value                                          = src.AudienceFilterScope_value
	Audience_AudienceExclusionDurationMode_name                        = src.Audience_AudienceExclusionDurationMode_name
	Audience_AudienceExclusionDurationMode_value                       = src.Audience_AudienceExclusionDurationMode_value
	ChangeHistoryResourceType_name                                     = src.ChangeHistoryResourceType_name
	ChangeHistoryResourceType_value                                    = src.ChangeHistoryResourceType_value
	CustomDimension_DimensionScope_name                                = src.CustomDimension_DimensionScope_name
	CustomDimension_DimensionScope_value                               = src.CustomDimension_DimensionScope_value
	CustomMetric_MeasurementUnit_name                                  = src.CustomMetric_MeasurementUnit_name
	CustomMetric_MeasurementUnit_value                                 = src.CustomMetric_MeasurementUnit_value
	CustomMetric_MetricScope_name                                      = src.CustomMetric_MetricScope_name
	CustomMetric_MetricScope_value                                     = src.CustomMetric_MetricScope_value
	CustomMetric_RestrictedMetricType_name                             = src.CustomMetric_RestrictedMetricType_name
	CustomMetric_RestrictedMetricType_value                            = src.CustomMetric_RestrictedMetricType_value
	DataRetentionSettings_RetentionDuration_name                       = src.DataRetentionSettings_RetentionDuration_name
	DataRetentionSettings_RetentionDuration_value                      = src.DataRetentionSettings_RetentionDuration_value
	DataStream_DataStreamType_name                                     = src.DataStream_DataStreamType_name
	DataStream_DataStreamType_value                                    = src.DataStream_DataStreamType_value
	File_google_analytics_admin_v1alpha_access_report_proto            = src.File_google_analytics_admin_v1alpha_access_report_proto
	File_google_analytics_admin_v1alpha_analytics_admin_proto          = src.File_google_analytics_admin_v1alpha_analytics_admin_proto
	File_google_analytics_admin_v1alpha_audience_proto                 = src.File_google_analytics_admin_v1alpha_audience_proto
	File_google_analytics_admin_v1alpha_resources_proto                = src.File_google_analytics_admin_v1alpha_resources_proto
	GoogleSignalsConsent_name                                          = src.GoogleSignalsConsent_name
	GoogleSignalsConsent_value                                         = src.GoogleSignalsConsent_value
	GoogleSignalsState_name                                            = src.GoogleSignalsState_name
	GoogleSignalsState_value                                           = src.GoogleSignalsState_value
	IndustryCategory_name                                              = src.IndustryCategory_name
	IndustryCategory_value                                             = src.IndustryCategory_value
	LinkProposalInitiatingProduct_name                                 = src.LinkProposalInitiatingProduct_name
	LinkProposalInitiatingProduct_value                                = src.LinkProposalInitiatingProduct_value
	LinkProposalState_name                                             = src.LinkProposalState_name
	LinkProposalState_value                                            = src.LinkProposalState_value
	PropertyType_name                                                  = src.PropertyType_name
	PropertyType_value                                                 = src.PropertyType_value
	ServiceLevel_name                                                  = src.ServiceLevel_name
	ServiceLevel_value                                                 = src.ServiceLevel_value
)

// To express that the result needs to be between two numbers (inclusive).
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessBetweenFilter = src.AccessBetweenFilter

// A contiguous range of days: startDate, startDate + 1, ..., endDate.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessDateRange = src.AccessDateRange

// Dimensions are attributes of your data. For example, the dimension
// `userEmail` indicates the email of the user that accessed reporting data.
// Dimension values in report responses are strings.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessDimension = src.AccessDimension

// Describes a dimension column in the report. Dimensions requested in a
// report produce column entries within rows and DimensionHeaders. However,
// dimensions used exclusively within filters or expressions do not produce
// columns in a report; correspondingly, those dimensions do not produce
// headers.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessDimensionHeader = src.AccessDimensionHeader

// The value of a dimension.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessDimensionValue = src.AccessDimensionValue

// An expression to filter dimension or metric values.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessFilter = src.AccessFilter

// Expresses dimension or metric filters. The fields in the same expression
// need to be either all dimensions or all metrics.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessFilterExpression = src.AccessFilterExpression

// A list of filter expressions.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessFilterExpressionList = src.AccessFilterExpressionList
type AccessFilterExpression_AccessFilter = src.AccessFilterExpression_AccessFilter
type AccessFilterExpression_AndGroup = src.AccessFilterExpression_AndGroup
type AccessFilterExpression_NotExpression = src.AccessFilterExpression_NotExpression
type AccessFilterExpression_OrGroup = src.AccessFilterExpression_OrGroup
type AccessFilter_BetweenFilter = src.AccessFilter_BetweenFilter
type AccessFilter_InListFilter = src.AccessFilter_InListFilter
type AccessFilter_NumericFilter = src.AccessFilter_NumericFilter
type AccessFilter_StringFilter = src.AccessFilter_StringFilter

// The result needs to be in a list of string values.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessInListFilter = src.AccessInListFilter

// The quantitative measurements of a report. For example, the metric
// `accessCount` is the total number of data access records.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessMetric = src.AccessMetric

// Describes a metric column in the report. Visible metrics requested in a
// report produce column entries within rows and MetricHeaders. However,
// metrics used exclusively within filters or expressions do not produce
// columns in a report; correspondingly, those metrics do not produce headers.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessMetricHeader = src.AccessMetricHeader

// The value of a metric.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessMetricValue = src.AccessMetricValue

// Filters for numeric or date values.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessNumericFilter = src.AccessNumericFilter

// The operation applied to a numeric filter.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessNumericFilter_Operation = src.AccessNumericFilter_Operation

// Order bys define how rows will be sorted in the response. For example,
// ordering rows by descending access count is one ordering, and ordering rows
// by the country string is a different ordering.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessOrderBy = src.AccessOrderBy
type AccessOrderBy_Dimension = src.AccessOrderBy_Dimension

// Sorts by dimension values.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessOrderBy_DimensionOrderBy = src.AccessOrderBy_DimensionOrderBy

// Rule to order the string dimension values by.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessOrderBy_DimensionOrderBy_OrderType = src.AccessOrderBy_DimensionOrderBy_OrderType
type AccessOrderBy_Metric = src.AccessOrderBy_Metric

// Sorts by metric values.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessOrderBy_MetricOrderBy = src.AccessOrderBy_MetricOrderBy

// Current state of all quotas for this Analytics property. If any quota for a
// property is exhausted, all requests to that property will return Resource
// Exhausted errors.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessQuota = src.AccessQuota

// Current state for a particular quota group.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessQuotaStatus = src.AccessQuotaStatus

// Access report data for each row.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessRow = src.AccessRow

// The filter for strings.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessStringFilter = src.AccessStringFilter

// The match type of a string filter.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccessStringFilter_MatchType = src.AccessStringFilter_MatchType

// A resource message representing a Google Analytics account.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type Account = src.Account

// A virtual resource representing an overview of an account and all its child
// GA4 properties.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AccountSummary = src.AccountSummary

// Request message for AcknowledgeUserDataCollection RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AcknowledgeUserDataCollectionRequest = src.AcknowledgeUserDataCollectionRequest

// Response message for AcknowledgeUserDataCollection RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AcknowledgeUserDataCollectionResponse = src.AcknowledgeUserDataCollectionResponse

// Types of actions that may change a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ActionType = src.ActionType

// Different kinds of actors that can make changes to Google Analytics
// resources.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ActorType = src.ActorType

// AnalyticsAdminServiceClient is the client API for AnalyticsAdminService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AnalyticsAdminServiceClient = src.AnalyticsAdminServiceClient

// AnalyticsAdminServiceServer is the server API for AnalyticsAdminService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AnalyticsAdminServiceServer = src.AnalyticsAdminServiceServer

// Request message for ApproveDisplayVideo360AdvertiserLinkProposal RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ApproveDisplayVideo360AdvertiserLinkProposalRequest = src.ApproveDisplayVideo360AdvertiserLinkProposalRequest

// Response message for ApproveDisplayVideo360AdvertiserLinkProposal RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ApproveDisplayVideo360AdvertiserLinkProposalResponse = src.ApproveDisplayVideo360AdvertiserLinkProposalResponse

// Request message for ArchiveAudience RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ArchiveAudienceRequest = src.ArchiveAudienceRequest

// Request message for ArchiveCustomDimension RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ArchiveCustomDimensionRequest = src.ArchiveCustomDimensionRequest

// Request message for ArchiveCustomMetric RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ArchiveCustomMetricRequest = src.ArchiveCustomMetricRequest

// The attribution settings used for a given property. This is a singleton
// resource.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AttributionSettings = src.AttributionSettings

// How far back in time events should be considered for inclusion in a
// converting path which leads to the first install of an app or the first
// visit to a site.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AttributionSettings_AcquisitionConversionEventLookbackWindow = src.AttributionSettings_AcquisitionConversionEventLookbackWindow

// How far back in time events should be considered for inclusion in a
// converting path for all conversions other than first app install/first site
// visit.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AttributionSettings_OtherConversionEventLookbackWindow = src.AttributionSettings_OtherConversionEventLookbackWindow

// The reporting attribution model used to calculate conversion credit in this
// property's reports.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AttributionSettings_ReportingAttributionModel = src.AttributionSettings_ReportingAttributionModel

// A resource message representing a GA4 Audience.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type Audience = src.Audience

// A specific filter for a single dimension or metric.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceDimensionOrMetricFilter = src.AudienceDimensionOrMetricFilter

// A filter for numeric or date values between certain values on a dimension
// or metric.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceDimensionOrMetricFilter_BetweenFilter = src.AudienceDimensionOrMetricFilter_BetweenFilter
type AudienceDimensionOrMetricFilter_BetweenFilter_ = src.AudienceDimensionOrMetricFilter_BetweenFilter_

// A filter for a string dimension that matches a particular list of options.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceDimensionOrMetricFilter_InListFilter = src.AudienceDimensionOrMetricFilter_InListFilter
type AudienceDimensionOrMetricFilter_InListFilter_ = src.AudienceDimensionOrMetricFilter_InListFilter_

// A filter for numeric or date values on a dimension or metric.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceDimensionOrMetricFilter_NumericFilter = src.AudienceDimensionOrMetricFilter_NumericFilter
type AudienceDimensionOrMetricFilter_NumericFilter_ = src.AudienceDimensionOrMetricFilter_NumericFilter_

// The operation applied to a numeric filter.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceDimensionOrMetricFilter_NumericFilter_Operation = src.AudienceDimensionOrMetricFilter_NumericFilter_Operation

// To represent a number.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceDimensionOrMetricFilter_NumericValue = src.AudienceDimensionOrMetricFilter_NumericValue
type AudienceDimensionOrMetricFilter_NumericValue_DoubleValue = src.AudienceDimensionOrMetricFilter_NumericValue_DoubleValue
type AudienceDimensionOrMetricFilter_NumericValue_Int64Value = src.AudienceDimensionOrMetricFilter_NumericValue_Int64Value

// A filter for a string-type dimension that matches a particular pattern.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceDimensionOrMetricFilter_StringFilter = src.AudienceDimensionOrMetricFilter_StringFilter
type AudienceDimensionOrMetricFilter_StringFilter_ = src.AudienceDimensionOrMetricFilter_StringFilter_

// The match type for the string filter.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceDimensionOrMetricFilter_StringFilter_MatchType = src.AudienceDimensionOrMetricFilter_StringFilter_MatchType

// A filter that matches events of a single event name. If an event parameter
// is specified, only the subset of events that match both the single event
// name and the parameter filter expressions match this event filter.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceEventFilter = src.AudienceEventFilter

// Specifies an event to log when a user joins the Audience.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceEventTrigger = src.AudienceEventTrigger

// Determines when to log the event.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceEventTrigger_LogCondition = src.AudienceEventTrigger_LogCondition

// A clause for defining either a simple or sequence filter. A filter can be
// inclusive (i.e., users satisfying the filter clause are included in the
// Audience) or exclusive (i.e., users satisfying the filter clause are
// excluded from the Audience).
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceFilterClause = src.AudienceFilterClause

// Specifies whether this is an include or exclude filter clause.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceFilterClause_AudienceClauseType = src.AudienceFilterClause_AudienceClauseType
type AudienceFilterClause_SequenceFilter = src.AudienceFilterClause_SequenceFilter
type AudienceFilterClause_SimpleFilter = src.AudienceFilterClause_SimpleFilter

// A logical expression of Audience dimension, metric, or event filters.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceFilterExpression = src.AudienceFilterExpression

// A list of Audience filter expressions.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceFilterExpressionList = src.AudienceFilterExpressionList
type AudienceFilterExpression_AndGroup = src.AudienceFilterExpression_AndGroup
type AudienceFilterExpression_DimensionOrMetricFilter = src.AudienceFilterExpression_DimensionOrMetricFilter
type AudienceFilterExpression_EventFilter = src.AudienceFilterExpression_EventFilter
type AudienceFilterExpression_NotExpression = src.AudienceFilterExpression_NotExpression
type AudienceFilterExpression_OrGroup = src.AudienceFilterExpression_OrGroup

// Specifies how to evaluate users for joining an Audience.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceFilterScope = src.AudienceFilterScope

// Defines filters that must occur in a specific order for the user to be a
// member of the Audience.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceSequenceFilter = src.AudienceSequenceFilter

// A condition that must occur in the specified step order for this user to
// match the sequence.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceSequenceFilter_AudienceSequenceStep = src.AudienceSequenceFilter_AudienceSequenceStep

// Defines a simple filter that a user must satisfy to be a member of the
// Audience.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type AudienceSimpleFilter = src.AudienceSimpleFilter

// Specifies how long an exclusion lasts for users that meet the exclusion
// filter.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type Audience_AudienceExclusionDurationMode = src.Audience_AudienceExclusionDurationMode

// Request message for CancelDisplayVideo360AdvertiserLinkProposal RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CancelDisplayVideo360AdvertiserLinkProposalRequest = src.CancelDisplayVideo360AdvertiserLinkProposalRequest

// A description of a change to a single Google Analytics resource.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ChangeHistoryChange = src.ChangeHistoryChange

// A snapshot of a resource as before or after the result of a change in
// change history.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ChangeHistoryChange_ChangeHistoryResource = src.ChangeHistoryChange_ChangeHistoryResource
type ChangeHistoryChange_ChangeHistoryResource_Account = src.ChangeHistoryChange_ChangeHistoryResource_Account
type ChangeHistoryChange_ChangeHistoryResource_AttributionSettings = src.ChangeHistoryChange_ChangeHistoryResource_AttributionSettings
type ChangeHistoryChange_ChangeHistoryResource_ConversionEvent = src.ChangeHistoryChange_ChangeHistoryResource_ConversionEvent
type ChangeHistoryChange_ChangeHistoryResource_CustomDimension = src.ChangeHistoryChange_ChangeHistoryResource_CustomDimension
type ChangeHistoryChange_ChangeHistoryResource_CustomMetric = src.ChangeHistoryChange_ChangeHistoryResource_CustomMetric
type ChangeHistoryChange_ChangeHistoryResource_DataRetentionSettings = src.ChangeHistoryChange_ChangeHistoryResource_DataRetentionSettings
type ChangeHistoryChange_ChangeHistoryResource_DataStream = src.ChangeHistoryChange_ChangeHistoryResource_DataStream
type ChangeHistoryChange_ChangeHistoryResource_DisplayVideo_360AdvertiserLink = src.ChangeHistoryChange_ChangeHistoryResource_DisplayVideo_360AdvertiserLink
type ChangeHistoryChange_ChangeHistoryResource_DisplayVideo_360AdvertiserLinkProposal = src.ChangeHistoryChange_ChangeHistoryResource_DisplayVideo_360AdvertiserLinkProposal
type ChangeHistoryChange_ChangeHistoryResource_FirebaseLink = src.ChangeHistoryChange_ChangeHistoryResource_FirebaseLink
type ChangeHistoryChange_ChangeHistoryResource_GoogleAdsLink = src.ChangeHistoryChange_ChangeHistoryResource_GoogleAdsLink
type ChangeHistoryChange_ChangeHistoryResource_GoogleSignalsSettings = src.ChangeHistoryChange_ChangeHistoryResource_GoogleSignalsSettings
type ChangeHistoryChange_ChangeHistoryResource_MeasurementProtocolSecret = src.ChangeHistoryChange_ChangeHistoryResource_MeasurementProtocolSecret
type ChangeHistoryChange_ChangeHistoryResource_Property = src.ChangeHistoryChange_ChangeHistoryResource_Property

// A set of changes within a Google Analytics account or its child properties
// that resulted from the same cause. Common causes would be updates made in
// the Google Analytics UI, changes from customer support, or automatic Google
// Analytics system changes.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ChangeHistoryEvent = src.ChangeHistoryEvent

// Types of resources whose changes may be returned from change history.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ChangeHistoryResourceType = src.ChangeHistoryResourceType

// A conversion event in a Google Analytics property.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ConversionEvent = src.ConversionEvent

// Request message for CreateAudience RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CreateAudienceRequest = src.CreateAudienceRequest

// Request message for CreateConversionEvent RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CreateConversionEventRequest = src.CreateConversionEventRequest

// Request message for CreateCustomDimension RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CreateCustomDimensionRequest = src.CreateCustomDimensionRequest

// Request message for CreateCustomMetric RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CreateCustomMetricRequest = src.CreateCustomMetricRequest

// Request message for CreateDataStream RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CreateDataStreamRequest = src.CreateDataStreamRequest

// Request message for CreateDisplayVideo360AdvertiserLinkProposal RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CreateDisplayVideo360AdvertiserLinkProposalRequest = src.CreateDisplayVideo360AdvertiserLinkProposalRequest

// Request message for CreateDisplayVideo360AdvertiserLink RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CreateDisplayVideo360AdvertiserLinkRequest = src.CreateDisplayVideo360AdvertiserLinkRequest

// Request message for CreateFirebaseLink RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CreateFirebaseLinkRequest = src.CreateFirebaseLinkRequest

// Request message for CreateGoogleAdsLink RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CreateGoogleAdsLinkRequest = src.CreateGoogleAdsLinkRequest

// Request message for CreateMeasurementProtocolSecret RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CreateMeasurementProtocolSecretRequest = src.CreateMeasurementProtocolSecretRequest

// Request message for CreateProperty RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CreatePropertyRequest = src.CreatePropertyRequest

// A definition for a CustomDimension.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CustomDimension = src.CustomDimension

// Valid values for the scope of this dimension.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CustomDimension_DimensionScope = src.CustomDimension_DimensionScope

// A definition for a custom metric.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CustomMetric = src.CustomMetric

// Possible types of representing the custom metric's value. Currency
// representation may change in the future, requiring a breaking API change.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CustomMetric_MeasurementUnit = src.CustomMetric_MeasurementUnit

// The scope of this metric.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CustomMetric_MetricScope = src.CustomMetric_MetricScope

// Labels that mark the data in this custom metric as data that should be
// restricted to specific users.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type CustomMetric_RestrictedMetricType = src.CustomMetric_RestrictedMetricType

// Settings values for data retention. This is a singleton resource.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DataRetentionSettings = src.DataRetentionSettings

// Valid values for the data retention duration.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DataRetentionSettings_RetentionDuration = src.DataRetentionSettings_RetentionDuration

// A resource message representing data sharing settings of a Google Analytics
// account.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DataSharingSettings = src.DataSharingSettings

// A resource message representing a data stream.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DataStream = src.DataStream

// Data specific to Android app streams.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DataStream_AndroidAppStreamData = src.DataStream_AndroidAppStreamData
type DataStream_AndroidAppStreamData_ = src.DataStream_AndroidAppStreamData_

// The type of the data stream.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DataStream_DataStreamType = src.DataStream_DataStreamType

// Data specific to iOS app streams.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DataStream_IosAppStreamData = src.DataStream_IosAppStreamData
type DataStream_IosAppStreamData_ = src.DataStream_IosAppStreamData_

// Data specific to web streams.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DataStream_WebStreamData = src.DataStream_WebStreamData
type DataStream_WebStreamData_ = src.DataStream_WebStreamData_

// Request message for DeleteAccount RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DeleteAccountRequest = src.DeleteAccountRequest

// Request message for DeleteConversionEvent RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DeleteConversionEventRequest = src.DeleteConversionEventRequest

// Request message for DeleteDataStream RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DeleteDataStreamRequest = src.DeleteDataStreamRequest

// Request message for DeleteDisplayVideo360AdvertiserLinkProposal RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DeleteDisplayVideo360AdvertiserLinkProposalRequest = src.DeleteDisplayVideo360AdvertiserLinkProposalRequest

// Request message for DeleteDisplayVideo360AdvertiserLink RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DeleteDisplayVideo360AdvertiserLinkRequest = src.DeleteDisplayVideo360AdvertiserLinkRequest

// Request message for DeleteFirebaseLink RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DeleteFirebaseLinkRequest = src.DeleteFirebaseLinkRequest

// Request message for DeleteGoogleAdsLink RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DeleteGoogleAdsLinkRequest = src.DeleteGoogleAdsLinkRequest

// Request message for DeleteMeasurementProtocolSecret RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DeleteMeasurementProtocolSecretRequest = src.DeleteMeasurementProtocolSecretRequest

// Request message for DeleteProperty RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DeletePropertyRequest = src.DeletePropertyRequest

// A link between a GA4 property and a Display & Video 360 advertiser.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DisplayVideo360AdvertiserLink = src.DisplayVideo360AdvertiserLink

// A proposal for a link between a GA4 property and a Display & Video 360
// advertiser. A proposal is converted to a DisplayVideo360AdvertiserLink once
// approved. Google Analytics admins approve inbound proposals while Display &
// Video 360 admins approve outbound proposals.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type DisplayVideo360AdvertiserLinkProposal = src.DisplayVideo360AdvertiserLinkProposal

// A link between a GA4 property and a Firebase project.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type FirebaseLink = src.FirebaseLink

// Request message for GetAccount RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetAccountRequest = src.GetAccountRequest

// Request message for GetAttributionSettings RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetAttributionSettingsRequest = src.GetAttributionSettingsRequest

// Request message for GetAudience RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetAudienceRequest = src.GetAudienceRequest

// Request message for GetConversionEvent RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetConversionEventRequest = src.GetConversionEventRequest

// Request message for GetCustomDimension RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetCustomDimensionRequest = src.GetCustomDimensionRequest

// Request message for GetCustomMetric RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetCustomMetricRequest = src.GetCustomMetricRequest

// Request message for GetDataRetentionSettings RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetDataRetentionSettingsRequest = src.GetDataRetentionSettingsRequest

// Request message for GetDataSharingSettings RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetDataSharingSettingsRequest = src.GetDataSharingSettingsRequest

// Request message for GetDataStream RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetDataStreamRequest = src.GetDataStreamRequest

// Request message for GetDisplayVideo360AdvertiserLinkProposal RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetDisplayVideo360AdvertiserLinkProposalRequest = src.GetDisplayVideo360AdvertiserLinkProposalRequest

// Request message for GetDisplayVideo360AdvertiserLink RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetDisplayVideo360AdvertiserLinkRequest = src.GetDisplayVideo360AdvertiserLinkRequest

// Request message for GetGlobalSiteTag RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetGlobalSiteTagRequest = src.GetGlobalSiteTagRequest

// Request message for GetGoogleSignalsSettings RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetGoogleSignalsSettingsRequest = src.GetGoogleSignalsSettingsRequest

// Request message for GetMeasurementProtocolSecret RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetMeasurementProtocolSecretRequest = src.GetMeasurementProtocolSecretRequest

// Request message for GetProperty RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GetPropertyRequest = src.GetPropertyRequest

// Read-only resource with the tag for sending data from a website to a
// DataStream. Only present for web DataStream resources.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GlobalSiteTag = src.GlobalSiteTag

// A link between a GA4 property and a Google Ads account.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GoogleAdsLink = src.GoogleAdsLink

// Consent field of the Google Signals settings (i.e., whether the user has
// consented to the Google Signals terms of service.)
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GoogleSignalsConsent = src.GoogleSignalsConsent

// Settings values for Google Signals. This is a singleton resource.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GoogleSignalsSettings = src.GoogleSignalsSettings

// Status of the Google Signals settings (i.e., whether this feature has been
// enabled for the property).
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type GoogleSignalsState = src.GoogleSignalsState

// The category selected for this property, used for industry benchmarking.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type IndustryCategory = src.IndustryCategory

// An indication of which product the user initiated a link proposal from.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type LinkProposalInitiatingProduct = src.LinkProposalInitiatingProduct

// The state of a link proposal resource.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type LinkProposalState = src.LinkProposalState

// Status information for a link proposal.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type LinkProposalStatusDetails = src.LinkProposalStatusDetails

// Request message for ListAccountSummaries RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListAccountSummariesRequest = src.ListAccountSummariesRequest

// Response message for ListAccountSummaries RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListAccountSummariesResponse = src.ListAccountSummariesResponse

// Request message for ListAccounts RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListAccountsRequest = src.ListAccountsRequest

// Request message for ListAccounts RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListAccountsResponse = src.ListAccountsResponse

// Request message for ListAudiences RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListAudiencesRequest = src.ListAudiencesRequest

// Response message for ListAudiences RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListAudiencesResponse = src.ListAudiencesResponse

// Request message for ListConversionEvents RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListConversionEventsRequest = src.ListConversionEventsRequest

// Response message for ListConversionEvents RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListConversionEventsResponse = src.ListConversionEventsResponse

// Request message for ListCustomDimensions RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListCustomDimensionsRequest = src.ListCustomDimensionsRequest

// Response message for ListCustomDimensions RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListCustomDimensionsResponse = src.ListCustomDimensionsResponse

// Request message for ListCustomMetrics RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListCustomMetricsRequest = src.ListCustomMetricsRequest

// Response message for ListCustomMetrics RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListCustomMetricsResponse = src.ListCustomMetricsResponse

// Request message for ListDataStreams RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListDataStreamsRequest = src.ListDataStreamsRequest

// Response message for ListDataStreams RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListDataStreamsResponse = src.ListDataStreamsResponse

// Request message for ListDisplayVideo360AdvertiserLinkProposals RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListDisplayVideo360AdvertiserLinkProposalsRequest = src.ListDisplayVideo360AdvertiserLinkProposalsRequest

// Response message for ListDisplayVideo360AdvertiserLinkProposals RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListDisplayVideo360AdvertiserLinkProposalsResponse = src.ListDisplayVideo360AdvertiserLinkProposalsResponse

// Request message for ListDisplayVideo360AdvertiserLinks RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListDisplayVideo360AdvertiserLinksRequest = src.ListDisplayVideo360AdvertiserLinksRequest

// Response message for ListDisplayVideo360AdvertiserLinks RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListDisplayVideo360AdvertiserLinksResponse = src.ListDisplayVideo360AdvertiserLinksResponse

// Request message for ListFirebaseLinks RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListFirebaseLinksRequest = src.ListFirebaseLinksRequest

// Response message for ListFirebaseLinks RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListFirebaseLinksResponse = src.ListFirebaseLinksResponse

// Request message for ListGoogleAdsLinks RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListGoogleAdsLinksRequest = src.ListGoogleAdsLinksRequest

// Response message for ListGoogleAdsLinks RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListGoogleAdsLinksResponse = src.ListGoogleAdsLinksResponse

// Request message for ListMeasurementProtocolSecret RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListMeasurementProtocolSecretsRequest = src.ListMeasurementProtocolSecretsRequest

// Response message for ListMeasurementProtocolSecret RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListMeasurementProtocolSecretsResponse = src.ListMeasurementProtocolSecretsResponse

// Request message for ListProperties RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListPropertiesRequest = src.ListPropertiesRequest

// Response message for ListProperties RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ListPropertiesResponse = src.ListPropertiesResponse

// A secret value used for sending hits to Measurement Protocol.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type MeasurementProtocolSecret = src.MeasurementProtocolSecret

// To represent a number.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type NumericValue = src.NumericValue
type NumericValue_DoubleValue = src.NumericValue_DoubleValue
type NumericValue_Int64Value = src.NumericValue_Int64Value

// A resource message representing a Google Analytics GA4 property.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type Property = src.Property

// A virtual resource representing metadata for a GA4 property.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type PropertySummary = src.PropertySummary

// Types of Property resources.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type PropertyType = src.PropertyType

// Request message for ProvisionAccountTicket RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ProvisionAccountTicketRequest = src.ProvisionAccountTicketRequest

// Response message for ProvisionAccountTicket RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ProvisionAccountTicketResponse = src.ProvisionAccountTicketResponse

// The request for a Data Access Record Report.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type RunAccessReportRequest = src.RunAccessReportRequest

// The customized Data Access Record Report response.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type RunAccessReportResponse = src.RunAccessReportResponse

// Request message for SearchChangeHistoryEvents RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type SearchChangeHistoryEventsRequest = src.SearchChangeHistoryEventsRequest

// Response message for SearchAccounts RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type SearchChangeHistoryEventsResponse = src.SearchChangeHistoryEventsResponse

// Various levels of service for Google Analytics.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type ServiceLevel = src.ServiceLevel

// UnimplementedAnalyticsAdminServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type UnimplementedAnalyticsAdminServiceServer = src.UnimplementedAnalyticsAdminServiceServer

// Request message for UpdateAccount RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type UpdateAccountRequest = src.UpdateAccountRequest

// Request message for UpdateAttributionSettings RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type UpdateAttributionSettingsRequest = src.UpdateAttributionSettingsRequest

// Request message for UpdateAudience RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type UpdateAudienceRequest = src.UpdateAudienceRequest

// Request message for UpdateCustomDimension RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type UpdateCustomDimensionRequest = src.UpdateCustomDimensionRequest

// Request message for UpdateCustomMetric RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type UpdateCustomMetricRequest = src.UpdateCustomMetricRequest

// Request message for UpdateDataRetentionSettings RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type UpdateDataRetentionSettingsRequest = src.UpdateDataRetentionSettingsRequest

// Request message for UpdateDataStream RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type UpdateDataStreamRequest = src.UpdateDataStreamRequest

// Request message for UpdateDisplayVideo360AdvertiserLink RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type UpdateDisplayVideo360AdvertiserLinkRequest = src.UpdateDisplayVideo360AdvertiserLinkRequest

// Request message for UpdateGoogleAdsLink RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type UpdateGoogleAdsLinkRequest = src.UpdateGoogleAdsLinkRequest

// Request message for UpdateGoogleSignalsSettings RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type UpdateGoogleSignalsSettingsRequest = src.UpdateGoogleSignalsSettingsRequest

// Request message for UpdateMeasurementProtocolSecret RPC
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type UpdateMeasurementProtocolSecretRequest = src.UpdateMeasurementProtocolSecretRequest

// Request message for UpdateProperty RPC.
//
// Deprecated: Please use types in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
type UpdatePropertyRequest = src.UpdatePropertyRequest

// Deprecated: Please use funcs in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
func NewAnalyticsAdminServiceClient(cc grpc.ClientConnInterface) AnalyticsAdminServiceClient {
	return src.NewAnalyticsAdminServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/analytics/admin/apiv1alpha/adminpb
func RegisterAnalyticsAdminServiceServer(s *grpc.Server, srv AnalyticsAdminServiceServer) {
	src.RegisterAnalyticsAdminServiceServer(s, srv)
}
